@@ -7,9 +7,9 @@
 static const R_FortranMethodDef FortranEntries[] = {
     {"dmmf",          (DL_FUNC) &F77_SUB(dmmf),          61},
     {"dmmfc",         (DL_FUNC) &F77_SUB(dmmfc),         64},
-    {"ke",            (DL_FUNC) &F77_SUB(ke),             5},
-    {"mdinf",         (DL_FUNC) &F77_SUB(mdinf),          1},
-    {"slope",         (DL_FUNC) &F77_SUB(slope),          3},
+//    {"ke",            (DL_FUNC) &F77_SUB(ke),             5},
+//    {"mdinf",         (DL_FUNC) &F77_SUB(mdinf),          1},
+//    {"slope",         (DL_FUNC) &F77_SUB(slope),          3},
     {"sinkfill",      (DL_FUNC) &F77_SUB(sinkfill),       8},
     {"checkboundary", (DL_FUNC) &F77_SUB(checkboundary),  4},
     {"mapchecker",    (DL_FUNC) &F77_SUB(mapchecker),     6},
